@@ -6,7 +6,7 @@ use lib 'lib';
 
 package File::Util;
 {
-  $File::Util::VERSION = '4.130590'; # TRIAL
+  $File::Util::VERSION = '4.130610'; # TRIAL
 }
 
 use File::Util::Definitions qw( :all );
@@ -2826,9 +2826,7 @@ sub AUTOLOAD {
    }
    elsif ( exists $redirect_methods->{ $name } ) {
 
-      ## no critic
       { no strict 'refs'; *{ $name } = $redirect_methods->{ $name } }
-      ## use critic
 
       goto \&$name;
    }
@@ -2855,7 +2853,7 @@ File::Util - Easy, versatile, portable file handling
 
 =head1 VERSION
 
-version 4.130590
+version 4.130610
 
 =head1 DESCRIPTION
 
@@ -2883,11 +2881,11 @@ I<(See L<DOCUMENTATION|/DOCUMENTATION> section below.)>
    # create a new File::Util object
    my $f = File::Util->new();
 
-   # load a file into a variable
+   # read file into a variable
    my $content = $f->load_file( 'some_file.txt' );
 
    # write content to a file
-   $f->write_file( 'another_file.txt' => $content );
+   $f->write_file( 'some_other_file.txt' => 'Hello world!' );
 
    # get the contents of a directory, 3 levels deep
    my @songs = $f->list_dir( '~/Music' => { recurse => 1, max_depth => 3 } );
@@ -2909,7 +2907,7 @@ need is here.
 
 =item B<The Manual>
 
-The L<File::Util::Manual> is the complete reference document explaing every
+The L<File::Util::Manual> is the complete reference document explaining every
 available feature and object method.  Use this to look up the full information
 on any given feature when the examples aren't enough.
 
@@ -2940,19 +2938,13 @@ that use File::Util to easily accomplish tasks which require file handling.
 =head2 File Operations
 
    # load content into a variable, be it text, or binary, either works
-   my $content = $f->load_file( 'Meeting Notes.txt' );
-
-   # ...or do it with diagnostics, for just for this call
-   $content = $f->load_file( 'Meeting Notes.txt' => { diag => 1 } );
+   my $content = $f->load_file( 'data.txt' );
 
    # wrangle some text
    $content =~ s/this/that/g;
 
-   # re-write the file with your changes
-   $f->write_file(
-      file => 'Meeting Notes.txt',
-      content => $content,
-   );
+   # write a file with your changes
+   $f->write_file( 'new_data.txt' => $content );
 
    # try binary this time
    my $binary_content = $f->load_file( 'barking-cat.avi' );
@@ -2962,13 +2954,10 @@ that use File::Util to easily accomplish tasks which require file handling.
 
    # ...and write a binary image file, using some other options as well
    $f->write_file(
-      file => 'llama.jpg',
-      content => $picture_data,
-      { binmode => 1, bitmask => oct 644 }
+      'llama.jpg' => $picture_data => { binmode => 1, bitmask => oct 644 }
    );
 
-   # ...or write a file with UTF-8 encoding (unicode support), using the
-   # short notation: write_file( [file name] => [content] => { options } )
+   # ...or write a file with UTF-8 encoding (unicode support)
    $f->write_file( 'encoded.txt' => qq(\x{c0}) => { binmode => 'utf8' } );
 
    # load a file into an array, line by line
@@ -2977,10 +2966,7 @@ that use File::Util to easily accomplish tasks which require file handling.
    # see if you have permission to write to a file, then append to it
    if ( $f->is_writable( 'captains.log' ) ) {
 
-      my $fh = $f->open_handle(
-         file => 'captains.log',
-         mode => 'append'
-      );
+      my $fh = $f->open_handle( 'captains.log' => 'append' );
 
       print $fh "Captain's log, stardate 41153.7.  Our destination is...";
 
@@ -2997,24 +2983,31 @@ that use File::Util to easily accomplish tasks which require file handling.
 =head2 File Handles
 
    # get an open file handle for reading
-   my $fh = $f->open_handle( file => 'Ian likes cats.txt', mode => 'read' );
+   my $fh = $f->open_handle( 'Ian likes cats.txt' => 'read' );
 
    while ( my $line = <$fh> ) { # read the file, line by line
-
       # ... do stuff
    }
 
-   close $fh or die $!; # don't forget to close ;-)
+   # get an open file handle for writing the same way
+   $fh = $f->open_handle( 'John prefers dachshunds.txt' => 'write' );
 
-   # get an open file handle for writing
+   # You add the option to turn on UTF-8 strict encoding for your reads/writes
    $fh = $f->open_handle(
-      file => 'John prefers dachshunds.txt',
-      mode => 'write'
+      'John prefers dachshunds.txt' => 'write' => { binmode => 'utf8' }
    );
 
-   print $fh 'Shout out to Bob!';
+   print $fh "Bob is happy! \N{U+263A}"; # << unicode smiley face!
 
-   close $fh or die $!; # don't forget to close ;-)
+   # you can use sysopen to get low-level with your file handles if needed
+   $fh = $f->open_handle(
+      'alderaan.txt' => 'rwclobber' => { use_sysopen => 1 }
+   );
+
+   syswrite $fh, "that's no moon";
+
+   # ...you can use any of these syswrite modes, also with { binmode => 'utf8' }
+   # read, write, append, rwcreate, rwclobber, rwappend, rwupdate, and trunc
 
 =head2 Directories
 
@@ -3030,22 +3023,12 @@ that use File::Util to easily accomplish tasks which require file handling.
       }
    );
 
-   # walk a directory, using an anonymous function or function ref as a
-   # callback (higher order Perl)
+   # walk a directory, using an anonymous function or function ref as a callback
    $f->list_dir( '/home/larry' => {
       recurse  => 1,
       callback => sub {
          my ( $selfdir, $subdirs, $files ) = @_;
-
-         print "In $selfdir there are...\n";
-
-         print scalar @$subdirs . " subdirectories, and ";
-         print scalar @$files   . " files\n";
-
-         for my $file ( @$files ) {
-
-            # ... do something with $file
-         }
+         # do stuff ...
       },
    } );
 
@@ -3063,7 +3046,7 @@ that use File::Util to easily accomplish tasks which require file handling.
    print 'My file was last modified on ' .
       scalar localtime $f->last_modified( 'my.file' );
 
-=head1 Getting Information About Your System's IO Capabilities
+=head2 Getting Information About Your System's IO Capabilities
 
    # Does your running Perl support unicode?
    print 'I support unicode' if $f->can_utf8;
@@ -3086,17 +3069,17 @@ error handlers, and more.
 
 =head1 PERFORMANCE
 
-File::Util has been optimized to run fast.*  In many scenarios it can
-out-perform other modules (like some of those listed in the SEE ALSO section)
-from anywhere from 100%-400% -- I<(See the benchmarking and profiling scripts>
-I<that are included as part of this distribution.)>
-
 File::Util consists of several modules, but only loads the ones it needs when
 it needs them and also offers a comparatively fast load-up time, so using
 File::Util doesn't bloat your code footprint.
 
-I<*Sometimes it doesn't matter how fast you can search through a directory 1000>
-I<times.  Performance alone isn't the best criteria for choosing a module.>
+Additionally, File::Util has been optimized to run fast.*  In many scenarios
+it does more and still out-performs other popular IO modules from anywhere
+from 100%-400%, although L<Path::Tiny> is also extremely fast at what it is
+designed to do.
+
+I<(See the benchmarking and profiling scripts>
+I<that are included as part of this distribution.)>
 
 =head1 METHODS
 
@@ -3199,19 +3182,27 @@ The following symbols comprise C<@File::Util::EXPORT_OK>), and as such are
 available for import to your namespace only upon request.  They can be
 used either as object methods or like regular subroutines in your program.
 
+   -  atomize_path        -  can_flock         -  can_utf8
+   -  created             -  diagnostic        -  ebcdic
+   -  escape_filename     -  existent          -  file_type
+   -  is_bin              -  is_readable       -  is_writable
+   -  last_access         -  last_changed      -  last_modified
+   -  needs_binmode       -  return_path       -  size
+   -  split_path          -  strip_path        -  valid_filename
+   -  NL and S L
+
 To get any of these functions/symbols into your namespace without having
-to use them as an object method, use this kind of syntax:
+to use them as object methods, use this kind of syntax:
 
-C<use File::Util qw( strip_path NL );>
+   use File::Util qw( strip_path return_path existent size );
 
-   * atomize_path      * can_flock         * can_utf8
-   * created           * diagnostic        * ebcdic
-   * escape_filename   * existent          * file_type
-   * is_bin            * is_readable       * is_writable
-   * last_access       * last_changed      * last_modified
-   * needs_binmode     * return_path       * size
-   * split_path        * strip_path        * valid_filename
-   * NL and SL
+   my $file  = $ARGV[0];
+   my $fname = strip_path( $file );
+   my $path  = return_path( $file );
+   my $size  = size( $file );
+
+   print qq(File "$fname" exists in "$path", and is $size bytes in size)
+      if existent( $file );
 
 =head2 EXPORT_TAGS
 
@@ -3219,18 +3210,19 @@ C<use File::Util qw( strip_path NL );>
 
    :diag (imports nothing to your namespace, it just enables diagnostics)
 
-You can use these tags alone, or in combination with individual symbols as
+You can use these tags alone, or in combination with other symbols as
 shown above.
 
 =head1 PREREQUISITES
 
 =over
 
-=item No External Prerequisites
+=item None.  There are no external prerequisite modules.
 
-File::Util only depends on modules that are part of the Core Perl distribution
+File::Util only depends on modules that are part of the Core Perl distribution,
+and you don't need a compiler on your system to install it.
 
-=item L<Perl|perl> 5.8.1 or better ...
+=item File::Util recommends L<Perl|perl> 5.8.1 or better ...
 
 You can technically run File::Util on older versions of Perl 5, but it isn't
 recommended, especially if you want unicode support and wish to take advantage
@@ -3274,6 +3266,40 @@ Clone it at L<git://github.com/tommybutler/file-util.git>
 
 This project was a private endeavor for too long so don't hesitate to pitch in.
 
+=head1 CONTRIBUTORS
+
+The following people have contributed to File::Util in the form of feedback,
+encouragement, recommendations, testing, or assistance with problems either
+on or offline in one form or another.  Listed in no particular order:
+
+=over
+
+=item *
+
+John Fields <jfields.cpan.org@spammenot.com>
+
+=item *
+
+BrowserUk <browseruk@cpan.org>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Matt S Trout <perl-stuff@trout.me.uk>
+
+=item *
+
+Nicholas Perez <nperez@cpan.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
 =head1 AUTHORS
 
 Tommy Butler L<http://www.atrixnet.com/contact>
@@ -3301,9 +3327,10 @@ This disclaimer applies to every part of the File::Util distribution.
 =head1 SEE ALSO
 
 The rest of the documentation:
-L<File::Util::Manual>, L<File::Util::Manual::Examples>, L<File::Util::Cookbook>,
+L<File::Util::Manual>, L<File::Util::Manual::Examples>, L<File::Util::Cookbook>
 
 Other Useful Modules that do similar things:
-L<File::Slurp>, L<File::Spec>, L<File::Find::Rule>, L<Path::Class>
+L<File::Slurp>, L<File::Spec>, L<File::Find::Rule>, L<Path::Class>,
+L<Path::Tiny>
 
 =cut
